@@ -6,7 +6,9 @@ Copyright (C) 2020 Luke Zhang
 """
 
 try: from CanvasPlus.canvasplus import CanvasPlus
-except:
+except ImportError:
     import sys
     print("Your python version %s is not compatible with the standard canvasplus library. For compatibility, another file is being imported." % sys.version)
-    from CanvasPlus.pythonBelow35 import CanvasPlus
\ No newline at end of file
+    from CanvasPlus.pythonBelow35 import CanvasPlus
+
+from CanvasPlus.templates import Template
\ No newline at end of file
